@@ -1,6 +1,6 @@
 // $URL: http://subversion:8080/svn/gsc/trunk/drivers/LINUX/SIO4%20and%20SIO8/SIO4_Linux_1.x.x_GSC_DN/samples/id/perform.c $
-// $Rev: 53078 $
-// $Date: 2023-06-13 10:07:36 -0500 (Tue, 13 Jun 2023) $
+// $Rev: 56757 $
+// $Date: 2026-01-07 08:27:16 -0600 (Wed, 07 Jan 2026) $
 
 // SIO4: Sample Application: source file
 
@@ -440,6 +440,45 @@ static int _query_u32(const int* fd, int query, const char* title, const char* s
 
 
 
+//*****************************************************************************
+static int _board_reset(const int* fd)
+{
+	int	errs	= 0;
+	int	i;
+	int	tmp;
+
+	gsc_label("Board Reset");
+
+	for (i = 0; i <= 3; i++)
+	{
+		if (i)
+		{
+			local_label_str("SKIP");
+			continue;
+		}
+
+		tmp	= sio4_ioctl(fd[i], SIO4_INIT_BOARD, NULL);
+
+		if (tmp)
+		{
+			local_label_str("FAIL <---");
+			errs++;
+		}
+		else
+		{
+			local_label_str("PASS");
+		}
+	}
+
+	if (errs)
+		printf("FAIL <---");
+
+	printf("\n");
+	return(errs);
+}
+
+
+
 //*****************************************************************************
 static int _query_form_factor(const int* fd)
 {
@@ -1272,6 +1311,11 @@ int perform_tests(const args_t* args)
 	s32	fw_type;
 	int	usc		= 0;
 
+	// This has been added as a recovery option when some boards start
+	// returning invalid values for the Zilog version number. The value
+	// returned is usually 0x0000.
+	errs	+= _board_reset(args->fd);
+
 	// Identification =====================================
 	gsc_label("Identification");
 	printf("\n");
